<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Google\Client;
use App\Models\Alert;

define('FIREBASE_API_KEY', 'YOUR_FIREBASE_API_KEY');

class AlertsController extends Controller
{
    public function allPersonalAlerts(Request $request)
    {
        // Your existing method implementation
    }

    public function createAlert(Request $request)
    {
        // Your existing method implementation
    }

    public function send($registration_ids, $notificationTitle, $notificationBody)
    {
        $accessToken = $this->getAccessToken(); // Retrieve the Bearer token

        foreach ($registration_ids as $registration_id) {
            $fields = [
                'message' => [
                    'token' => $registration_id,
                    'notification' => [
                        'title' => $notificationTitle,
                        'body' => $notificationBody,
                        'image' => 'https://eastleighxp.com/phyneselfhelp/public/smallest_logo.png',
                    ],
                    'data' => [
                        'title' => $notificationTitle,
                        'body' => $notificationBody,
                        'sound' => 'default',
                        'image' => 'https://eastleighxp.com/phyneselfhelp/public/smallest_logo.png',
                    ],
                ],
            ];

            $response = $this->sendPushNotification($fields, $accessToken);
            $this->storeAlertInDatabase($registration_id, $notificationTitle, $notificationBody);


            Log::info("Response from send method for token $registration_id: " . $response);
        }

        return response()->json(['success' => true, 'message' => 'Alerts sent successfully.']);
    }

    public function sendPushNotification($fields, $accessToken)
    {
        $url = 'https://fcm.googleapis.com/v1/projects/phynetechselfhelp/messages:send';

        $headers = [
            'Authorization: Bearer ' . $accessToken,
            'Content-Type: application/json',
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));

        $result = curl_exec($ch);
        if ($result === false) {
            die('Curl failed: ' . curl_error($ch));
        }

        curl_close($ch);
        return $result;
    }

    public function getAccessToken()
    {
        $client = new Client();
        $client->setAuthConfig(storage_path('app/service-account.json'));
        $client->addScope('https://www.googleapis.com/auth/firebase.messaging');

        $token = $client->fetchAccessTokenWithAssertion();
        return $token['access_token'];
    }

    public function sendAlert(Request $request)
    {
        $pushMessage = $request->message;
        $pushTitle = $request->title;
        $id = $request->userID;

        //Log::info("Sending alert to user ID: $id with title: $pushTitle and message: $pushMessage");

        $deviceID = DB::table("users")
            ->where("id", $id)
            ->pluck("deviceid");

        //Log::info("Retrieved device ID: " . json_encode($deviceID));

        if ($deviceID->isEmpty()) {
            Log::error("No device ID found for user ID: $id");
            return response()->json(['success' => false, 'message' => 'No device ID found.'], 404);
        }

        $response = $this->send($deviceID, $pushTitle, $pushMessage);

        //Log::info("Response from send method: " . $response);

        return response()->json(['success' => true, 'message' => 'Alert sent successfully.']);
    }
    public function sendAlertToAllUsers(Request $request)
{
    $pushMessage = $request->message;
    $pushTitle = $request->title;

    // Log for debugging
    Log::info("Sending alert to all users with title: $pushTitle and message: $pushMessage");

    // Retrieve all device IDs from the users table
    $deviceIDs = DB::table("users")
        ->whereNotNull('deviceid') // Ensure that the device ID is not null
        ->pluck("deviceid");

    if ($deviceIDs->isEmpty()) {
        Log::error("No device IDs found for any user.");
        return response()->json(['success' => false, 'message' => 'No device IDs found.'], 404);
    }

    // Send the notification to all device IDs
    $response = $this->send($deviceIDs, $pushTitle, $pushMessage);

    // Log the response for debugging
    Log::info("Response from send method for all users: " . $response);

    return response()->json(['success' => true, 'message' => 'Alert sent to all users successfully.'],200);
}
public function storeAlertInDatabase($deviceId, $title, $message)
{
    // Get the user ID based on the device ID
    $userId = DB::table('users')
                ->where('deviceid', $deviceId)
                ->value('id'); // Get the user's ID

    if ($userId) {
        // Insert the notification into the alerts table
        DB::table('alerts')->insert([
            'userid' => $userId,
            'title' => $title,
            'message' => $message,
            'created_at' => now(),
            'updated_at' => now(),
        ]);

        //Log::info("Alert saved to database for user $userId.");
    } else {
        Log::error("No user found for device ID $deviceId.");
    }
}
public function getUserAlerts(Request $request)
    {
        // Validate the request to ensure 'userid' is provided
        $validated = $request->validate([
            'userid' => 'required|integer|exists:users,id',
            'page' => 'nullable|integer|min:1',
            'size' => 'nullable|integer|min:1|max:100',
        ]);

        // Extract user ID and pagination info from the request
        $userId = $validated['userid'];
        $page = $validated['page'] ?? 1;
        $pageSize = $validated['size'] ?? 20;

        // Fetch alerts for the user with pagination
        $alerts = DB::table('alerts')
             ->where('userid', $userId)
            ->orderBy('created_at', 'desc')
            ->skip(($page - 1) * $pageSize)
            ->take($pageSize)
            ->get();

        // Return the alerts in JSON format with pagination
        return response()->json([
            'status' => 'success',
            'alerts' => $alerts,
            'currentPage' => $page,
            'pageSize' => $pageSize,
        ]);
    }
    public function markAlertAsRead($id)
    {
        
        DB::table('alerts')->where('id', $id)->update(['isRead' => 1]);
         return response()->json([
            'success' => true,
            'message' => 'Alert marked as read.',
        ],200);
    }
    // Mark all alerts as read for a specific user
    public function markAllAsRead(Request $request)
    {
        // Get userId from request parameters
        $userId = $request->query('userid');

        try {
            // Update all alerts for the given user to mark them as read
            DB::table('alerts')
                ->where('userid', $userId)
                ->update(['isRead' => 1]);

            return response()->json([
                'success' => true,
                'message' => 'All alerts marked as read.',
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Failed to mark all alerts as read.',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
}




