<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Contribution; // Assuming this is your model for contributions
use App\Models\Loan;         // Assuming this is your model for loans

class PersonalDashBoardController extends Controller
{
    /**
     * Get loan balance and total contributions for a specific user.
     *
     * @param  int  $userId
     * @return \Illuminate\Http\JsonResponse
     */
    public function getLoanBalanceAndContributions($userId)
    {
        try {
            // Fetch total contributions for the user from the contributions table
            $totalContributions = Contribution::where('memberId', $userId)
                 ->where('approved',true)
                ->sum('amount'); // Sum all contributions

            // Fetch total loan balance for the user from the loans table
            $loanBalance = Loan::where('memberId', $userId)
                ->where('admin1_approved', true)
                ->where('admin2_approved', true) 
                ->sum('amount'); // Sum all unpaid loan balances

            // Return the total contributions and loan balance
            return response()->json([
                'contributions' => $totalContributions,
                'loanBalance' => $loanBalance,
            ], 200);

        } catch (\Exception $e) {
            // Handle any errors
            return response()->json([
                'message' => 'Error fetching data',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
}
