<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AlertsController;
use App\Jobs\SendAlertJob;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Mail;

class RegisterController extends Controller
{
   public function register(Request $request)
{
    // Validate the request data
    $validator = Validator::make($request->all(), [
        'fname' => 'required|string|max:50',
        'IdNumber' =>  'required|string|max:10|unique:users,IdNumber',
        'lname' => 'required|string|max:50',
        'phone' => 'required|string|max:10|unique:users,phone',
        'email' => 'required|string|email|max:255|unique:users,email',
        'password' => 'required|string|min:3', // password_confirmation must match
    ]);

    if ($validator->fails()) {
        $errorMessages = $validator->errors()->all(); // Returns an array of all error messages

        // Merge the error messages into a single string
        $mergedErrors = implode(' ', $errorMessages);

        return response()->json([
            'status' => 'error',
            'message' => $mergedErrors, // Single message with all errors
        ], 422);
    }

    // Get the current number of users
    $usersCount = User::count();
    $memberNumber = now()->format('Y') . str_pad($usersCount + 1, 2, '0', STR_PAD_LEFT);


    // Create and save the user
    $user = User::create([
        'fname' => $request->input('fname'),
        'lname' => $request->input('lname'),
        'phone' => $request->input('phone'),
        'email' => $request->input('email'),
        'IdNumber' => $request->input('IdNumber'),
        'password' => Hash::make($request->input('password')), // Hash the password
        'memberNumber' => $memberNumber, // Assign the generated member number
    ]);
    // Send email with registration details using Blade template
    $data = [
        'fname' => $user->fname,
        'lname' => $user->lname,
        'email' => $user->email,
        'IdNumber' => $user->IdNumber,
        'phone' => $user->phone,
        'memberNumber' => $user->memberNumber,
        'password' => $request->input('password'), // Plain password
        'themeColor' => '#127E09' // Theme color
    ];

    Mail::send('emails.registration', $data, function($message) use ($user) {
        $message->to($user->email)
            ->subject('Welcome to Phynetech');
    });

    return response()->json([
        'status' => 'success',
        'message' => 'User registered successfully. Member Number: ' . $memberNumber, // Include member number in the response
        'user' => $user,
    ], 200);
}

    public function activateOrDeactivateUser(Request $request)
    {
        $userId = $request->input('id');
        $newStatus = $request->input('status'); // true for activate, false for deactivate

      
        $user = User::find($userId);

        if (!$user) {
            return response()->json([
                'code' => 0,
                'message' => 'User not found.',
            ], 404);
        }

       
        $user->active = $newStatus;

        try {
            $user->save();
             $fullname=$user->fname.' '.$user->lname;
            // **6. Return Success Response**
            return response()->json([
                'code' => 1,
                'message' => $newStatus ? $fullname.' activated successfully.' : $fullname.' deactivated successfully.',
                'data' => $user,
            ], 200);
        } catch (\Exception $e) {
            // **7. Handle Exceptions**
            return response()->json([
                'code' => 0,
                'message' => 'An error occurred while updating user status.',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
    public function switchUserRole(Request $request)
{
    // **2. Retrieve Validated Data**
    $userId = $request->input('id');
    $newRole = $request->input('role'); // 1 for Admin, 0 for User

    // **3. Find the User**
    $user = User::find($userId);

    if (!$user) {
        return response()->json([
            'code' => 0,
            'message' => 'User not found.',
        ], 404);
    }

    // **4. Update the User's Role**
    $user->role = $newRole;

    try {
        $user->save();
        $fullname=$user->fname.' '.$user->lname;

        // **5. Return Success Response**
        return response()->json([
            'message' => $user->role === "1" ? $fullname. ' has promoted to Admin successfully.' :  $fullname. ' demoted to Member successfully.',
        ], 200);
    } catch (\Exception $e) {
        // **6. Handle Exceptions**
        return response()->json([
            'code' => 0,
            'message' => 'An error occurred while updating user role.',
            'error' => $e->getMessage(),
        ], 500);
    }
}

    public function updateMemberDetails(Request $request)
    {
        // **3. Retrieve and Update User**
        $user = User::find($request->input('id'));
        $fullname=$user->fname.' '.$user->lname;

        $user->fname = $request->input('fname');
        $user->lname = $request->input('lname');
        $user->phone = $request->input('phone');
        $user->email = $request->input('email');
        $user->idNumber = $request->input('idNumber');

        try {
            $user->save();

            // **4. Return Success Response**
            return response()->json([
                'code' => 1,
                'message' =>  $fullname.' details updated successfully.',
                
            ], 200);
            // $alertData = new Request([
            //     'userID' =>  $validated['memberId'],
            //     'title' => 'Order Confirmation',
            //     'message' => 'Your order has been placed successfully.',
            // ]);
            // (new AlertsController())->sendAlert($alertData);
        } catch (\Exception $e) {
            // **5. Handle Exceptions**
            return response()->json([
                'code' => 0,
                'message' => 'An error occurred while updating member details.',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
    
    public function updateDeviceId(Request $request)
{
    User::where('id', $request->id)->update([
        'deviceid' => $request->deviceid
    ]);
}



public function resetPassword(Request $request)
{
    // Validate that the prompt and value are provided
    $request->validate([
        'prompt' => 'required|string',
        'value' => 'required|string', 
        'password'=>'required|string',
       
    ]);

    try {
        $column = $request->value;
        // Find the user by the selected column (without checking the PIN)
        $user = User::where($column, $request->prompt)->first();

        // If no user found with the provided prompt
        if (!$user) {
            return response()->json([
                'status' => 'error',
                'message' => 'Details did not match our records.',  // Generalized message
            ], 404);
        }
        $user->password = Hash::make($request->password);
        $user->save();
        
       $alertData = [
            'userID' => $user->id,
            'title' => "Account Security",
            'message' => "Hi  $user->fname, Someone has just modified your password. If that was not you consider changing your password immediately!",
        ];

        // Dispatch the SendAlertJob with a 2-second delay
        SendAlertJob::dispatch($alertData)->delay(now()->addSeconds(1));
        
        
        return response()->json([
            'status' => 'success',
            'message' => 'Your password has been updated..',
        ], 200);
    } catch (\Exception $e) {
        return response()->json([
            'status' => 'error',
            'message' => 'Failed to reset password.',
            'error' => $e->getMessage(),
        ], 500);
    }
}

public function updateEmail(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'userid' => 'required|integer|exists:users,id',
            'email'  => 'required|email|unique:users,email',
        ]);

        try {
            // Find the user by ID
            $user = User::findOrFail($validatedData['userid']);

            // Update the user's email
            $user->email = $validatedData['email'];
            $user->save();
            $alertData = [
            'userID' => $user->id,
            'title' => "Account Security",
            'message' => "Hi  $user->fname, Someone has just modified your account email. If that was not you consider changing your password immediately!",
        ];

        // Dispatch the SendAlertJob with a 2-second delay
        SendAlertJob::dispatch($alertData)->delay(now()->addSeconds(1));
            // Return a success response
            return response()->json([
                'message' => 'Email updated successfully.',
                'status'  => 'success',
            ], 200);

        } catch (\Exception $e) {
            // Handle exceptions
            return response()->json([
                'message' => 'An error occurred while updating the email.',
                'status'  => 'error',
                'error'   => $e->getMessage(),
            ], 500);
        }
    }


    public function updatePassword(Request $request)
{
    // Validate the incoming request data
    $validatedData = $request->validate([
        'userid' => 'required|integer|exists:users,id',
        'password' => 'required|string|min:4',
    ]);

    try {
        $user = User::findOrFail($validatedData['userid']);
        // Update the user's password
        $user->password = Hash::make($validatedData['password']);
        $user->save();
        $alertData = [
            'userID' => $user->id,
            'title' => "Account Security",
            'message' => "Hi  $user->fname, Someone has just modified your password. If that was not you consider changing your password immediately!",
        ];

        // Dispatch the SendAlertJob with a 2-second delay
        SendAlertJob::dispatch($alertData)->delay(now()->addSeconds(1));
        // Return a success response
        return response()->json([
            'message' => 'Password updated successfully.',
            'status'  => 'success',
        ], 200);

    } catch (\Exception $e) {
        // Handle exceptions
        return response()->json([
            'message' => 'An error occurred while updating the password.',
            'status'  => 'error',
            'error'   => $e->getMessage(),
        ], 500);
    }
}



    public function uploadProfilePicture(Request $request)
    {
        // Validate the incoming request data
        $request->validate([
            'userid' => 'required|integer|exists:users,id',
            'image' => 'required|image|max:2048', // Max size 2MB
        ]);

        // Retrieve the user by ID
        $user = User::find($request->input('userid'));

        if (!$user) {
            return response()->json([
                'message' => 'User not found.',
            ], 404);
        }

        // Remove existing profile picture if it exists
        if ($user->image) {
            $existingPhotoPath = public_path('profilepictures/' . $user->image);
            if (file_exists($existingPhotoPath)) {
                unlink($existingPhotoPath);
            }
        }

        // Handle the uploaded image
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $filename = 'user_' . $user->id . '_' . time() . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path('profilepictures');

            // Move the file to the destination path
            $image->move($destinationPath, $filename);

            // Update user's profile picture path in the database
            $user->image = $filename;
            $user->save();

            return response()->json([
                'message' => 'Profile picture updated successfully.',
                'profile_picture' => $filename,
            ], 200);
        } else {
            return response()->json([
                'message' => 'No image uploaded.',
            ], 400);
        }
    }
}






  
   




