<!DOCTYPE html>
<html>
<head>
    <title>Loan Approval Form - {{ $loan->loanId }}</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 0;
            color: #333;
            line-height: 1.6;
        }

        .container {
            width: 100%;
            padding: 20px;
        }

        .header {
            text-align: center;
            padding: 10px;
            border-bottom: 2px solid #333;
        }

        h1 {
            font-size: 22px;
            text-transform: uppercase;
            letter-spacing: 1px;
        }

        table {
            width: 100%;
            margin: 20px 0;
            border-collapse: collapse;
        }

        table th, table td {
            padding: 10px;
            border: 1px solid #333;
        }

        th {
            background-color: #f2f2f2;
            text-align: left;
            font-weight: bold;
        }

        .details-table td {
            font-size: 14px;
        }

        .signature-box {
            margin-top: 30px;
            padding-top: 20px;
            text-align: left;
        }

        .signer {
            margin-bottom: 10px;
        }

        .signature-line {
            border-top: 1px solid #000;
            margin-top: 40px;
            padding-top: 5px;
            width: 50%;
        }

        .centered {
            text-align: center;
        }
    </style>
</head>
<body>

<div class="container">
    <div class="header">
        <h1>Loan Approval Form</h1>
    </div>

    <h2>Loan Details</h2>
    <table class="details-table">
        <tr>
            <th>Loan ID</th>
            <td>{{ $loan->loanId }}</td>
        </tr>
        <tr>
            <th>Amount</th>
            <td>KES {{ number_format($loan->amount, 2) }}</td>
        </tr>
        <tr>
            <th>Borrower</th>
            <td>{{ $user->fname }} {{ $user->lname }}</td>
        </tr>
        <tr>
            <th>Loan Term</th>
            <td>{{ $loan->duration }} months</td>
        </tr>
        <tr>
            <th>Interest Rate</th>
            <td>{{ $loan->interest }}%</td>
        </tr>
        <tr>
            <th>Approval Date</th>
            <td>{{ $loan->approved_at }}</td>
        </tr>
    </table>

    <h2>Guarantor(s) Details</h2>
    @if (!empty($loan->guarantors) && is_array($loan->guarantors) && count($loan->guarantors) > 0)
        <table class="details-table">
            <thead>
            <tr>
                <th>Guarantor Name</th>
                <th>Member No.</th>
                <th>Shares</th>
                <th>Accepted Date</th>
                <th>Signature</th>
            </tr>
            </thead>
            <tbody>
            @foreach ($loan->guarantors as $guarantor)
                <tr>
                    <td>{{ $guarantor['fname'] }} {{ $guarantor['lname'] }}</td>
                    <td>{{ $guarantor['member_number'] }}</td>
                    <td>{{ number_format($guarantor['shares'], 2) }}</td>
                    <td>{{ $guarantor['accepted_at'] }}</td>
                    <td class="signature-box">
                        Signed on {{ $guarantor['accepted_at'] }}
                    </td>
                </tr>
            @endforeach
            </tbody>
        </table>
    @else
        <p>No guarantors associated with this loan.</p>
    @endif

    <div class="signature-box">
        <p class="signer">Admin Approval Signature: ________________________</p>
        <p class="signer">Date: {{ now()->format('Y-m-d') }}</p>
    </div>
</div>

</body>
</html>
