<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\LoginController;
use App\Http\Controllers\RegisterController;
use App\Http\Controllers\TransactionTypeController;
use App\Http\Controllers\ContributionController;
use App\Http\Controllers\LoanController;
use App\Http\Controllers\PersonalDashBoardController;
use App\Http\Controllers\AlertsController;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Log;

//users

Route::post('/users/activate', [RegisterController::class, 'activateOrDeactivateUser']);
Route::post('/users/switch-role', [RegisterController::class, 'switchUserRole']);
Route::post('/login', [LoginController::class, 'login']);
Route::post('/register', [RegisterController::class, 'register']);
Route::get('/all-users/{userId}', [LoginController::class, 'listUsers']);
Route::get('/users/{id}', [LoginController::class, 'getUserById']);
Route::post('/upload-profile-picture', [RegisterController::class, 'uploadProfilePicture']);


Route::post('/users/update-member-details', [RegisterController::class, 'updateMemberDetails']);
Route::post('/update-device-id', [RegisterController::class, 'updateDeviceId']);
Route::post('/reset-password', [RegisterController::class, 'resetPassword']);
Route::post('/update-email', [RegisterController::class, 'updateEmail']);
Route::post('/password/update', [RegisterController::class, 'updatePassword']);


//send alerts
Route::post('/send-alert-to-all', [AlertsController::class, 'sendAlertToAllUsers']);
//fecth alerts for specfic user
Route::get('/alerts', [AlertsController::class, 'getUserAlerts']);
Route::put('/alerts/{id}/mark-read', [AlertsController::class, 'markAlertAsRead']);
Route::put('/alerts/mark-all-read', [AlertsController::class, 'markAllAsRead']);
//email
Route::get('/test-email', function () {
    try {
        Mail::raw('This is a test email from Phynetech Selfhelp Group.', function ($message) {
            $message->to('cantosauric@gmail.com') // Replace with your test email address
                    ->subject('Test Email from Phynetech');
        });
        return 'Test email sent!';
    } catch (\Exception $e) {
        Log::error('Mail Error: ' . $e->getMessage());  // Log the error
        return 'Failed to send email: ' . $e->getMessage();
    }
});








// Ensure only authenticated users can access this route
Route::get('/transaction-types', [TransactionTypeController::class, 'index']);
//contributions
Route::get('/contributions', [ContributionController::class, 'index']);
Route::post('/contributions', [ContributionController::class, 'store']);
Route::get('/contributions/{id}', [ContributionController::class, 'show']);
Route::put('/contributions/{id}', [ContributionController::class, 'update']);
Route::delete('/contributions/{id}', [ContributionController::class, 'destroy']);
Route::put('/contributions/{id}/update-status', [ContributionController::class, 'updateApprovalStatus']);
// For API routes in routes/api.php
Route::get('/users/{userId}/contributions', [ContributionController::class, 'getUserContributions']);


//loans


Route::get('/loans', [LoanController::class, 'index']);          // Get all loans
Route::post('/loans', [LoanController::class, 'store']);         // Create a new loan
Route::get('/loans/{id}', [LoanController::class, 'show']);      // Get a specific loan by ID
Route::put('/loans/{id}', [LoanController::class, 'update']);    // Update a loan by ID
Route::delete('/loans/{id}', [LoanController::class, 'destroy']); // Delete a loan by ID
Route::get('/applicant-info/{id}', [LoanController::class, 'getApplicantInfo']);
// Route to get pending loans by userID
Route::get('/pending-loans/{userID}', [LoanController::class, 'getPendingLoans']);
Route::get('/user/{userID}/loans', [LoanController::class, 'getUserLoans']);
Route::get('/user/loans', [LoanController::class, 'getAllLoans']);
Route::post('approve-loan/{loanId}/{adminId}', [LoanController::class, 'approveLoan']);
Route::post('/loan/{id}/accept', [LoanController::class, 'acceptLoan']);
//loan-payments
Route::post('/loanpayments', [LoanController::class, 'addPayment']);
Route::get('/loanpayments', [LoanController::class, 'fetchLoanPayments']);
Route::put('/loanpayments/{id}', [LoanController::class, 'updatePayment']);
Route::delete('/loanpayments/{id}', [LoanController::class, 'deletePayment']);
Route::put('/loanpayments/{id}/update-status', [LoanController::class, 'updatePaymentStatus']);






//dashboard
Route::get('/dashboard/{userId}', [PersonalDashBoardController::class, 'getLoanBalanceAndContributions']);
Route::get('/loan-dashboard/{userId}', [LoanController::class, 'getLoanDashboardData']);
Route::get('/loan-dashboard/being-guaranteed/{userId}', [LoanController::class, 'getGuaranteedLoans']);









Route::get('/user', function (Request $request) {
    return $request->user();
})->middleware('auth:sanctum');
